# ![logo](/docs/images/vinplots.logo.svg)

[![PyPI pyversions](https://img.shields.io/pypi/pyversions/vinplots.svg)](https://pypi.python.org/pypi/vinplots/)
[![PyPI version](https://badge.fury.io/py/vinplots.svg)](https://badge.fury.io/py/vinplots)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


[Michael Vinyard](https://github.com/mvinyard)'s python plotting assistant
